%global giturl  https://github.com/ocaml/opam

Name:           opam
Version:        2.3.0
Release:        %mkrel 1
Summary:        A source-based package manager for OCaml
Group:		Development/OCaml
License:        LGPL-2.1-only WITH OCaml-LGPL-linking-exception
URL:            https://opam.ocaml.org/
VCS:            git:%{giturl}.git
Source0:        %{giturl}/releases/download/%{version}/%{name}-full-%{version}.tar.gz
Source1:        %{giturl}/releases/download/%{version}/%{name}-full-%{version}.tar.gz.sig
Source2:        https://opam.ocaml.org/opam-dev-pubkey.pgp
 
BuildRequires:  diffutils
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  gnupg2
BuildRequires:  libacl-devel
BuildRequires:  make
BuildRequires:  ocaml >= 4.08.0
BuildRequires:  ocaml-base64-devel >= 3.1.0
BuildRequires:  ocaml-cmdliner-devel >= 1.1.0
BuildRequires:  ocaml-cudf-devel >= 0.7
BuildRequires:  ocaml-dose3-devel >= 6.1
BuildRequires:  ocaml-dune >= 2.8.0
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-jsonm-devel
BuildRequires:  ocaml-mccs-devel
BuildRequires:  ocaml-ocamlgraph-devel
BuildRequires:  ocaml-opam-0install-cudf-devel >= 0.5.0
BuildRequires:  ocaml-opam-file-format-devel >= 2.1.4
BuildRequires:  ocaml-re-devel >= 1.10.0
BuildRequires:  ocaml-sha-devel >= 1.13
BuildRequires:  ocaml-spdx-licenses-devel >= 1.0.0
BuildRequires:  ocaml-swhid-core-devel
BuildRequires:  ocaml-uutf-devel
BuildRequires:  openssl

# Needed to install packages and run opam init.
Requires:       bubblewrap
Requires:       bzip2
Requires:       diffutils
Requires:       gcc
Requires:       gzip
Requires:       make
Requires:       m4
Requires:       patch
Requires:       tar
Requires:       unzip
Requires:       xz

Requires:       opam-installer%{?_isa} = %{version}-%{release}

Obsoletes:      opam-doc < 2.1.3-2

%description
Opam is a source-based package manager for OCaml. It supports multiple
simultaneous compiler installations, flexible package constraints, and
a Git-friendly development workflow.

%package installer
Summary:        Standalone script for opam install files

%description installer
Standalone script for working with opam .install files, see the opam
package for more information.

%prep
%{gpgverify} --data=%{SOURCE0} --signature=%{SOURCE1} --keyring=%{SOURCE2}
%autosetup -n %{name}-full-%{version} -p1

%build
export DUNE_ARGS='--verbose'
export DUNE_PROFILE_ARG='release'

%configure
%make_build

%install
export DUNE_ARGS='--verbose'
export DUNE_PROFILE_ARG='release'
%make_install

# However it looks like some (extra) documentation gets
# installed in the wrong place so... delete it.
rm -rf %{buildroot}%{_prefix}/doc

# It seems that some tests fail under mock.
# I am not sure why at the moment. So for now I'll just turn them off.
#%%check
#make tests

%files
%license LICENSE
%{_bindir}/opam
%exclude %{_mandir}/man1/opam-installer.1*
%{_mandir}/man1/*.1*

%files installer
%license LICENSE
# Upstream puts this documentation under opam-installer, not opam.
# Since I have opam require opam-installer anyway, this seems reasonable.
# (And there are lots of man pages in the opam package, so it has docs).
%doc README.md CHANGES AUTHORS CONTRIBUTING.md
%{_bindir}/opam-installer
%{_mandir}/man1/opam-installer.1*


%changelog
* Sat Apr 05 2025 pterjan <pterjan> 2.3.0-1.mga10
+ Revision: 2173882
- Update to 2.3.0

* Sun Sep 11 2022 neoclust <neoclust> 2.1.3-1.mga9
+ Revision: 1886888
- New version  2.1.3

* Sun May 15 2022 pterjan <pterjan> 2.1.2-1.mga9
+ Revision: 1858193
- Update to 2.1.2
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Mar 27 2021 tv <tv> 2.0.6-5.mga9
+ Revision: 1710816
- Rebuild for ocaml-4.12

* Tue Jun 02 2020 daviddavid <daviddavid> 2.0.6-3.mga8
+ Revision: 1589684
- add upstream patch to fix build
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 2.0.6-1.mga8
+ Revision: 1485287
- new release + rebuild for ocaml-4.10
- new release + rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x
+ daviddavid <daviddavid>
- new version: 2.0.2

* Thu Oct 18 2018 daviddavid <daviddavid> 2.0.1-1.mga7
+ Revision: 1322092
- new version: 2.0.1

* Tue Oct 02 2018 daviddavid <daviddavid> 2.0.0-4.mga7
+ Revision: 1315867
- add some additional required pkgs

* Sun Sep 23 2018 umeabot <umeabot> 2.0.0-3.mga7
+ Revision: 1299970
- Mageia 7 Mass Rebuild

* Wed Aug 22 2018 daviddavid <daviddavid> 2.0.0-2.mga7
+ Revision: 1253358
- new version: 2.0.0 (Final)

* Wed Jan 31 2018 tv <tv> 2.0.0-1.mga7
+ Revision: 1198286
- new release 2.0.0-beta6
- use %%license

* Fri Oct 13 2017 daviddavid <daviddavid> 1.2.2-3.mga7
+ Revision: 1171471
- rebuild for fixed ocaml (use standard ISO C99 types {u}uint{32,64}_t)

* Mon Sep 26 2016 pterjan <pterjan> 1.2.2-2.mga6
+ Revision: 1056456
- Rebuild for fix in ocaml

* Tue Feb 09 2016 pterjan <pterjan> 1.2.2-1.mga6
+ Revision: 951002
- Update to 1.2.2
- Update to 1.2.2
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild
+ daviddavid <daviddavid>
- fix License
- fix Group
- use %%configure2_5x and %%makeinstall_std
+ blue_prawn <blue_prawn>
- update from RC1 to final release
- increm mkrel
- the new booter may work
+ malo <malo>
- add missing buildrequires

* Wed Oct 16 2013 blue_prawn <blue_prawn> 1.1.0-1.mga4
+ Revision: 501615
- from beta to official release
- from beta to official release

* Mon Sep 23 2013 blue_prawn <blue_prawn> 1.1.0-1.beta.mga4
+ Revision: 484358
- try with the "ocp-build.boot" of the previous version
- updated to last version 1.1.0-beta
- make Opam able to open .tar.lzma and .tar.xz archives

* Mon Apr 01 2013 blue_prawn <blue_prawn> 1.0.0-1.mga3
+ Revision: 407071
- build requires camlp4
- imported package opam

